@@ -1,9 +1,9 @@
 require_dependency "diaspora_federation/application_controller"
 
 module DiasporaFederation
-  # this controller processes fetch requests
+  # This controller processes fetch requests.
   class FetchController < ApplicationController
-    # returns the fetched entity or a redirect
+    # Returns the fetched entity or a redirect
     #
     # GET /fetch/:type/:guid
     def fetch
@@ -29,7 +29,7 @@ module DiasporaFederation
     end
 
     def create_magic_envelope(entity)
-      privkey = DiasporaFederation.callbacks.trigger(:fetch_private_key_by_diaspora_id, entity.author)
+      privkey = DiasporaFederation.callbacks.trigger(:fetch_private_key, entity.author)
       Salmon::MagicEnvelope.new(entity, entity.author).envelop(privkey) if privkey
     end
   end
