@@ -1,7 +1,11 @@
 DiasporaFederation::Engine.routes.draw do
   controller :receive do
-    post "receive-new/public"      => :public,  :as => "receive_public"
-    post "receive-new/users/:guid" => :private, :as => "receive_private"
+    post "receive/public"      => :public,  :as => "receive_public"
+    post "receive/users/:guid" => :private, :as => "receive_private"
+  end
+
+  controller :fetch do
+    get "fetch/:type/:guid" => :fetch, :as => "fetch"
   end
 
   controller :webfinger do
